@@ -58,6 +58,70 @@ test_that("withTags works", {
   expect_identical(tags$p(100), foo())
 })
 
+test_that(".noWS argument of withTags()", {
+  get_noWS <- function(tag) tag[[".noWS"]]
+
+  default <- withTags(
+    div(
+      class = "myclass",
+      h3("header"),
+      p("One", strong(span("two")), "three")
+    )
+  )
+
+  expect_null(get_noWS(default))
+  expect_null(get_noWS(default$children[[1]]))
+  expect_null(get_noWS(default$children[[2]]))
+  expect_null(get_noWS(default$children[[2]]$children[[2]]))
+  expect_null(get_noWS(default$children[[2]]$children[[2]]$children[[1]]))
+
+  default_special <- withTags(
+    div(
+      class = "myclass",
+      h3("header", .noWS = "after-begin"),
+      p("One", strong(span("two")), "three", .noWS = "before-end")
+    )
+  )
+
+  expect_null(get_noWS(default_special))
+  expect_equal(get_noWS(default_special$children[[1]]), "after-begin")
+  expect_equal(get_noWS(default_special$children[[2]]), "before-end")
+  expect_null(get_noWS(default_special$children[[2]]$children[[2]]))
+  expect_null(get_noWS(default_special$children[[2]]$children[[2]]$children[[1]]))
+
+  all_same_noWS <- c("outside", "inside")
+  all_same <- withTags(
+    div(
+      class = "myclass",
+      h3("header"),
+      p("One", strong(span("two")), "three")
+    ),
+    .noWS = all_same_noWS
+  )
+
+  expect_equal(get_noWS(all_same), all_same_noWS)
+  expect_equal(get_noWS(all_same$children[[1]]), all_same_noWS)
+  expect_equal(get_noWS(all_same$children[[2]]), all_same_noWS)
+  expect_equal(get_noWS(all_same$children[[2]]$children[[2]]), all_same_noWS)
+  expect_equal(get_noWS(all_same$children[[2]]$children[[2]]$children[[1]]), all_same_noWS)
+
+  varied_default <- "outside"
+  varied_special <- "inside"
+  varied <- withTags(
+    div(
+      class = "myclass",
+      h3("header"),
+      p("One", strong(span("two"), .noWS = varied_special), "three")
+    ),
+    .noWS = varied_default
+  )
+
+  expect_equal(get_noWS(varied), varied_default)
+  expect_equal(get_noWS(varied$children[[1]]), varied_default)
+  expect_equal(get_noWS(varied$children[[2]]), varied_default)
+  expect_equal(get_noWS(varied$children[[2]]$children[[2]]), varied_special)
+  expect_equal(get_noWS(varied$children[[2]]$children[[2]]$children[[1]]), varied_default)
+})
 
 test_that("HTML escaping in tags", {
   # Regular text is escaped
@@ -100,7 +164,10 @@ test_that("Adding child tags", {
   t2 <- tagAppendChild(t2, tag_list[[3]])
   t2a <- do.call(tags$div, c(tag_list, class="foo"))
   expect_identical(t2a, t2)
-
+  t2b <- tagAppendChildren(div_tag, `names_are_ignored` = tag_list[[1]],
+    "ignore-this-name" = tag_list[[2]],
+    dummyName = tag_list[[3]])
+  expect_identical(t2b, t2)
 
   # tagSetChildren, using list argument
   t2 <- tagSetChildren(div_tag, list = tag_list)
@@ -110,6 +177,10 @@ test_that("Adding child tags", {
   t2 <- tagSetChildren(div_tag, tag_list[[1]], tag_list[[2]], tag_list[[3]])
   expect_identical(t2a, t2)
 
+  # tagSetChildren, using named ... arguments (names should be ignored)
+  t2 <- tagSetChildren(div_tag, ignored = tag_list[[1]], dummy = tag_list[[2]], blah = tag_list[[3]])
+  expect_identical(t2a, t2)
+
   # tagSetChildren, using ... and list arguments
   t2 <- tagSetChildren(div_tag, tag_list[[1]], list = tag_list[2:3])
   expect_identical(t2a, t2)
@@ -366,6 +437,17 @@ test_that("Adding attributes to tags", {
     list(class = "c1 c2", class = "c3")
   )
 
+  # Adding empty attributes
+  expect_identical(
+    tagAppendAttributes(t1, class = NULL)$attribs,
+    list()
+  )
+  expect_identical(
+    tagAppendAttributes(
+      tagAppendAttributes(t1, class = "hidden"), class = NULL)$attribs,
+    list(class = "hidden")
+  )
+
   t2 <- tags$div("foo", class = "c1")
 
   # Adding attributes on a tag with other attributes
@@ -381,6 +463,25 @@ test_that("Adding attributes to tags", {
   )
 })
 
+test_that("Adding unnamed attributes creates a warning", {
+  expect_error(
+    tagAppendAttributes(
+      tags$div(),
+      "value"
+    ),
+    "include an attribute name"
+  )
+
+  x <- div()
+  x$attribs[[1]] <- "value"
+  expect_error(
+    print(x),
+    "name all of your attribute values"
+  )
+})
+
+
+
 test_that("Testing for attributes on tags", {
   t1 <- tags$div("foo", class = "c1", class = "c2", id = "foo")
 
@@ -508,6 +609,57 @@ test_that("NA attributes are rendered correctly", {
   )
 })
 
+test_that("NA attributes are retrieved correctly", {
+  expect_foo_attr <- function(y, ...) {
+    testTag <- tags$div("text", ...)
+    expect_identical(
+      tagGetAttribute(testTag, "foo"),
+      y
+    )
+  }
+  expect_foo_attr(NA, foo = NA)
+  expect_foo_attr(NA, class = "a", foo = NA)
+  expect_foo_attr(NA, class = "a", foo = NA, class = "b")
+
+  # Multiple NA's are coalesced
+  expect_foo_attr(NA, class = "a", foo = NA, class = "b", foo = NA)
+
+  # A non-NA value supersedes NA
+  expect_foo_attr("b", class = "a", foo = NA, foo = "b")
+  expect_foo_attr("b c", class = "a", foo = "b", foo = NA, foo = "c")
+  expect_foo_attr("b c", class = "a", foo = "b", foo = NA, foo = NA, foo = "c")
+
+  # Non atomic value cause a list to be returned.
+  expect_foo_attr(list(list("b")), class = "a", foo = NA, foo = list("b"))
+  expect_foo_attr(list(list("b"), list("c")), class = "a", foo = list("b"), foo = NA, foo = list("c"))
+  expect_foo_attr(list("b", list("c")), class = "a", foo = "b", foo = NA, foo = NA, foo = list("c"))
+})
+
+test_that("Tag list tree is rendered in DOM tree order", {
+  # Tree order is preorder, depth-first traversal
+  # https://dom.spec.whatwg.org/#concept-tree
+  #
+  # Test for preordered traversal/execution of tagFunction(). This allows one to
+  # rely on the side-effects of executing a tag, so long as those side-effects
+  # happen "towards the top" of the tree. Shiny implicitly assumes this
+  # behavior: execution of bootstrapLib() introduces a (temporary) side-effect
+  # that "down-stream" UI (i.e. sliderInput() et al) can use to inform their
+  # Sass -> CSS compilation
+  value <- NULL
+  lazyDiv <- div(tagFunction(function() { value }))
+  dom <- tagList(
+    lazyDiv,
+    div(tagList(
+      tagFunction(function() { value <<- 1 })
+    )),
+    lazyDiv
+  )
+  expect_identical(
+    as.character(dom),
+    "<div></div>\n<div>1</div>\n<div>1</div>"
+  )
+})
+
 
 test_that("Flattening a list of tags", {
   # Flatten a nested list
@@ -674,8 +826,8 @@ test_that("Indenting can be controlled/suppressed", {
 })
 
 test_that("cssList tests", {
-  expect_identical("", css())
-  expect_identical("", css())
+  expect_identical(NULL, css())
+  expect_identical(NULL, css())
   expect_identical(
     css(
       font.family = 'Helvetica, "Segoe UI"',
@@ -693,7 +845,7 @@ test_that("cssList tests", {
   expect_error(css(1, b=2))
 
   # NULL and empty string are dropped
-  expect_identical(css(a="", b = NULL, "c!" = NULL, d = character()), "")
+  expect_null(css(a="", b = NULL, "c!" = NULL, d = character()))
 
   # We are dumb about duplicated properties. Probably don't do that.
   expect_identical(css(a=1, a=2), "a:1;a:2;")
@@ -823,3 +975,181 @@ test_that("htmlEscape will try to coerce inputs to characters", {
     as.character(x)
   )
 })
+
+test_that("trailing commas allowed everywhere", {
+  expect_silent({
+    t1 <- div("foo",)
+    tagList(t1,)
+    tagSetChildren(t1, "child",)
+    tagAppendAttributes(t1, class = "bar",)
+    tagAppendChildren(t1, "child2",)
+    css(style = "",)
+  })
+})
+
+test_that("extractPreserveChunks works for emoji strings", {
+  # solaris doesn't seem to support Unicode characters with surrogate pairs
+  # (just by creating such a string will cause a warning)
+  # > "\U0001F937"
+  # [1] "\U0001f937"
+  # Warning message:
+  #   it is not known that wchar_t is Unicode on this platform
+  skip_on_os("solaris")
+  x <- "<!--html_preserve-->chunk1<!--/html_preserve-->\U0001F937<!--html_preserve-->chunk2<!--/html_preserve-->"
+  out <- extractPreserveChunks(x)
+  expect_equivalent(
+    out$chunks,
+    c('chunk2', 'chunk1')
+  )
+})
+
+
+test_that("complicated class attributes are handled", {
+  x <- div(class = as.factor(letters)[1], class = "b c", class = c("d", "e f"))
+  expect_equal(
+    tagGetAttribute(x, "class"),
+    "a b c d e f"
+  )
+  expect_identical(
+    as.character(x),
+    "<div class=\"a b c d e f\"></div>"
+  )
+})
+
+
+test_that("html render method", {
+  local_edition(3)
+
+  # Have a place holder div and return a span instead
+  obj <- div("example", .renderHook = function(x) {
+    x$name <- "span"
+    x
+  })
+  expect_equal(obj$name, "div")
+  expect_snapshot(as.character(obj))
+
+  # Add a class to the tag
+  spanExtra <- tagAddRenderHook(obj, function(x) {
+    tagAppendAttributes(x, class = "extra")
+  })
+  expect_equal(spanExtra$name, "div")
+  expect_equal(spanExtra$attribs$class, NULL)
+  expect_snapshot(as.character(spanExtra))
+
+  # Replace the previous render method
+  # Should print a `div` with class `"extra"`
+  divExtra <- tagAddRenderHook(obj, replace = TRUE, function(x) {
+    tagAppendAttributes(x, class = "extra")
+  })
+  expect_equal(divExtra$attribs$class, NULL)
+  expect_snapshot(as.character(divExtra))
+
+  # Add more child tags
+  spanExtended <- tagAddRenderHook(obj, function(x) {
+    tagAppendChildren(x, tags$strong("bold text"))
+  })
+  expect_equal(spanExtended$name, "div")
+  expect_equal(spanExtended$children, obj$children)
+  expect_snapshot(as.character(spanExtended))
+
+  tagFuncExt <- tagAddRenderHook(obj, function(x) {
+    tagFunction(function() tagList(x, tags$p("test")) )
+  })
+  expect_equal(tagFuncExt$name, "div")
+  expect_equal(tagFuncExt$children, obj$children)
+  expect_snapshot(as.character(tagFuncExt))
+
+  # Add a new html dependency
+  newDep <- tagAddRenderHook(obj, function(x) {
+    fa <- htmlDependency(
+      "font-awesome", "4.5.0", c(href="shared/font-awesome"),
+      stylesheet = "css/font-awesome.min.css")
+    attachDependencies(x, fa, append = TRUE)
+  })
+  # Also add a jqueryui html dependency
+  htmlDependencies(newDep) <- htmlDependency(
+    "jqueryui", "1.11.4", c(href="shared/jqueryui"),
+    script = "jquery-ui.min.js")
+  expect_equal(newDep$name, "div")
+  expect_length(htmlDependencies(newDep), 1)
+  expect_snapshot(renderTags(newDep))
+
+  # Ignore the original tag and return something completely new.
+  newObj <- tagAddRenderHook(obj, function(x) {
+    tags$p("Something else")
+  })
+  expect_equal(newObj$name, "div")
+  expect_snapshot(as.character(newObj))
+})
+
+
+test_that(".cssSelector arg only applies changes to the selected elements", {
+  html <-
+    div(
+      class = "outer",
+      div(class = "inner", "text"),
+      span("TEXT")
+    )
+
+  expect_equal_tags(
+    tagAppendAttributes(html, id = "test"),
+    div(class = "outer", id = "test", div(class="inner", "text"), span("TEXT"))
+  )
+  expect_equal_tags(
+    tagAppendAttributes(html, id = "test", .cssSelector = ".inner"),
+    div(class = "outer", div(class = "inner", id = "test", "text"), span("TEXT"))
+  )
+
+  expect_equal_tags(
+    tagAppendChild(html, h1()),
+    div(class = "outer", div(class="inner", "text"), span("TEXT"), h1())
+  )
+  expect_equal_tags(
+    tagAppendChild(html, h1(), .cssSelector = ".inner"),
+    div(class = "outer", div(class = "inner", "text", h1()), span("TEXT"))
+  )
+
+  expect_equal_tags(
+    tagAppendChildren(html, h1(), h2()),
+    div(class = "outer", div(class="inner", "text"), span("TEXT"), h1(), h2())
+  )
+  expect_equal_tags(
+    tagAppendChildren(html, h1(), h2(), .cssSelector = ".inner"),
+    div(class = "outer", div(class = "inner", "text", h1(), h2()), span("TEXT"))
+  )
+
+  expect_equal_tags(
+    tagSetChildren(html, h1(), h2()),
+    div(class = "outer", h1(), h2())
+  )
+  expect_equal_tags(
+    tagSetChildren(html, h1(), h2(), .cssSelector = ".inner"),
+    div(class = "outer", div(class = "inner", h1(), h2()), span("TEXT"))
+  )
+
+  expect_equal_tags(
+    tagInsertChildren(html, h1(), h2(), after = 0),
+    div(class = "outer", h1(), h2(), div(class="inner", "text"), span("TEXT"))
+  )
+  expect_equal_tags(
+    tagInsertChildren(html, h1(), h2(), after = 0, .cssSelector = ".inner"),
+    div(class = "outer", div(class = "inner", h1(), h2(), "text"), span("TEXT"))
+  )
+})
+
+
+
+
+test_that("flattenTagAttribs", {
+  attribs <- list(
+    b = "1",
+    a = "2",
+    b = "3"
+  )
+
+  flatAttribs <- flattenTagAttribs(attribs)
+  # alpha sorted
+  expect_equal(names(flatAttribs), c("a", "b"))
+  # b values are collected
+  expect_equal(flatAttribs, list(a = "2", b = c("1", "3")))
+})
